@@ -7,6 +7,7 @@ import pickle
 import shutil
 import sys
 import warnings
+from collections import defaultdict
 from copy import deepcopy
 from glob import glob
 from urllib.error import HTTPError
@@ -141,33 +142,56 @@ def parse_dependency(input_directory, text_column_name, language_column_name,
     if not os.path.isdir(out_dir):
         os.makedirs(out_dir)
 
-    def get_filename(text_filename):
-        name = os.path.splitext(os.path.basename(text_filename))[0] + '.pckl'
-        return os.path.join(output_column_name, name)
+    df[output_column_name] = [
+        os.path.join(
+            output_column_name,
+            os.path.splitext(os.path.basename(f))[0] + '.pckl'
+        )
+        for f in text_column_name
+    ]
 
-    df[output_column_name] = df[text_column_name].apply(get_filename)
-    tuples = [(in_file, out_file, language)
-              for (in_file, out_file, language)
-              in zip(df[text_column_name],
-                     df[output_column_name],
-                     df[language_column_name])
-              if (not os.path.isfile(os.path.join(input_directory, out_file)))
-              or overwrite]
+    def should_write(f):
+        if overwrite:
+            return True
+        if os.path.isfile(f):
+            return os.path.getsize(f) == 0
+        return False
+
+    tuples = [
+        (in_file, out_file, language)
+        for (in_file, out_file, language)
+        in zip(
+            df[text_column_name],
+            df[output_column_name],
+            df[language_column_name]
+        )
+        if should_write(os.path.join(input_directory, out_file))
+    ]
     if not tuples:
         logger.warning('no files remaining, skipping calculation')
         return
 
     parsers = {}
+    errors = defaultdict(list)
     for in_file, out_file, language in tqdm(tuples):
         if language.endswith('_to_en'):
             language = 'en'
         if language not in parsers:
             parsers[language] = stanza.Pipeline(lang=language, use_gpu=False)
         parser = parsers[language]
-        with open(os.path.join(input_directory, in_file)) as in_fh:
-            parsed = parser(in_fh.read())
-        with open(os.path.join(input_directory, out_file), 'wb') as out_fh:
-            pickle.dump(parsed, out_fh)
+
+        full_path = os.path.join(input_directory, in_file)
+        with open(full_path) as in_fh:
+            content = in_fh.read()
+            try:
+                parsed = parser(content)
+            except RuntimeError as e:
+                logger.error('error on parsing', full_path)
+                logger.error(content)
+                errors[full_path].append((e, content))
+                continue
+            with open(os.path.join(input_directory, out_file), 'wb') as out_fh:
+                pickle.dump(parsed, out_fh)
     logger.info('writing %s', main_dataset_file)
     df.to_csv(main_dataset_file, index=False)
 
